@@ -1,7 +1,7 @@
 package Bencher::Role::FieldMunger;
 
-our $DATE = '2020-01-12'; # DATE
-our $VERSION = '1.047'; # VERSION
+our $DATE = '2020-04-29'; # DATE
+our $VERSION = '1.048'; # VERSION
 
 use 5.010;
 use strict;
@@ -38,7 +38,7 @@ sub add_field {
             $unit = $opts->{unit};
         } elsif ($opts->{unit_of}) {
             for my $i (0..$#{$ff}) {
-                if ($ff->[$i] eq $opts->{unit_of}) {
+                if (($ff->[$i] // '') eq $opts->{unit_of}) {
                     $unit = $fu->[$i];
                     last;
                 }
@@ -101,7 +101,7 @@ Bencher::Role::FieldMunger - Field munger role
 
 =head1 VERSION
 
-This document describes version 1.047 of Bencher::Role::FieldMunger (from Perl distribution Bencher-Backend), released on 2020-01-12.
+This document describes version 1.048 of Bencher::Role::FieldMunger (from Perl distribution Bencher-Backend), released on 2020-04-29.
 
 =for Pod::Coverage .*
 
